diff --git a/core/includes/entity.inc b/core/includes/entity.inc
index 98acf56..53f04ea 100644
--- a/core/includes/entity.inc
+++ b/core/includes/entity.inc
@@ -468,19 +468,19 @@ function entity_get_form(EntityInterface $entity, $operation = 'default', array
 }
 
 /**
- * Returns an entity list controller for a given entity type.
+ * Returns an entity list builder for a given entity type.
  *
  * @param string $entity_type
  *   The type of the entity.
  *
- * @return \Drupal\Core\Entity\EntityListControllerInterface
- *   An entity list controller.
+ * @return \Drupal\Core\Entity\EntityListBuilderInterface
+ *   An entity list builder.
  *
- * @deprecated Use \Drupal\Core\Entity\EntityManagerInterface::getFormController().
+ * @deprecated Use \Drupal\Core\Entity\EntityManagerInterface::getListBuilder().
  */
 function entity_list_controller($entity_type) {
   return \Drupal::entityManager()
-    ->getListController($entity_type);
+    ->getListBuilder($entity_type);
 }
 
 /**
diff --git a/core/lib/Drupal/Core/Config/Entity/ConfigEntityListController.php b/core/lib/Drupal/Core/Config/Entity/ConfigEntityListBuilder.php
similarity index 77%
rename from core/lib/Drupal/Core/Config/Entity/ConfigEntityListController.php
rename to core/lib/Drupal/Core/Config/Entity/ConfigEntityListBuilder.php
index 54afad2..36394e9 100644
--- a/core/lib/Drupal/Core/Config/Entity/ConfigEntityListController.php
+++ b/core/lib/Drupal/Core/Config/Entity/ConfigEntityListBuilder.php
@@ -2,21 +2,21 @@
 
 /**
  * @file
- * Definition of Drupal\Core\Config\Entity\ConfigEntityListController.
+ * Contains \Drupal\Core\Config\Entity\ConfigEntityListBuilder.
  */
 
 namespace Drupal\Core\Config\Entity;
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityListController;
+use Drupal\Core\Entity\EntityListBuilder;
 
 /**
- * Defines the default list controller for ConfigEntity objects.
+ * Defines the default list builder for configuration entities.
  */
-class ConfigEntityListController extends EntityListController {
+class ConfigEntityListBuilder extends EntityListBuilder {
 
   /**
-   * Overrides Drupal\Core\Entity\EntityListController::load().
+   * {@inheritdoc}
    */
   public function load() {
     $entities = parent::load();
diff --git a/core/lib/Drupal/Core/Entity/Controller/EntityListController.php b/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
index 7a07a38..1b081bb 100644
--- a/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
+++ b/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
@@ -25,7 +25,7 @@ class EntityListController extends ControllerBase {
    *   A render array as expected by drupal_render().
    */
   public function listing($entity_type) {
-    return $this->entityManager()->getListController($entity_type)->render();
+    return $this->entityManager()->getListBuilder($entity_type)->render();
   }
 
 }
diff --git a/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php b/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php
index 31672c0..aac92bc 100644
--- a/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php
+++ b/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php
@@ -25,7 +25,7 @@ class EntityViewController implements ContainerInjectionInterface {
   protected $entityManager;
 
   /**
-   * Creates an EntityListController object.
+   * Creates an EntityViewController object.
    *
    * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
    *   The entity manager.
diff --git a/core/lib/Drupal/Core/Entity/EntityManager.php b/core/lib/Drupal/Core/Entity/EntityManager.php
index 8f7e929..6058e44 100644
--- a/core/lib/Drupal/Core/Entity/EntityManager.php
+++ b/core/lib/Drupal/Core/Entity/EntityManager.php
@@ -193,7 +193,7 @@ public function getStorageController($entity_type) {
   /**
    * {@inheritdoc}
    */
-  public function getListController($entity_type) {
+  public function getListBuilder($entity_type) {
     return $this->getController($entity_type, 'list', 'getListClass');
   }
 
diff --git a/core/lib/Drupal/Core/Entity/EntityTypeInterface.php b/core/lib/Drupal/Core/Entity/EntityTypeInterface.php
index 4305c6b..91be44a 100644
--- a/core/lib/Drupal/Core/Entity/EntityTypeInterface.php
+++ b/core/lib/Drupal/Core/Entity/EntityTypeInterface.php
@@ -194,7 +194,7 @@ public function getControllerClass($controller_type);
    *     entity forms when the forms are similar. The classes must implement
    *     \Drupal\Core\Entity\EntityFormControllerInterface.
    *   - list: The name of the class that provides listings of the entities. The
-   *     class must implement \Drupal\Core\Entity\EntityListControllerInterface.
+   *     class must implement \Drupal\Core\Entity\EntityListBuilderInterface.
    *   - render: The name of the class that is used to render the entities. The
    *     class must implement \Drupal\Core\Entity\EntityViewBuilderInterface.
    *   - access: The name of the class that is used for access checks. The class
diff --git a/core/modules/action/action.module b/core/modules/action/action.module
index cc6821b..a3a674f 100644
--- a/core/modules/action/action.module
+++ b/core/modules/action/action.module
@@ -79,7 +79,7 @@ function action_entity_info(&$entity_info) {
     ->setFormClass('add', 'Drupal\action\ActionAddFormController')
     ->setFormClass('edit', 'Drupal\action\ActionEditFormController')
     ->setFormClass('delete', 'Drupal\action\Form\ActionDeleteForm')
-    ->setListClass('Drupal\action\ActionListController')
+    ->setListClass('Drupal\action\ActionListBuilder')
     ->setLinkTemplate('delete-form', 'action.delete')
     ->setLinkTemplate('edit-form', 'action.admin_configure');
 }
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockListController.php b/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockListBuilder.php
similarity index 82%
rename from core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockListController.php
rename to core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockListBuilder.php
index 1f49a87..419db27 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockListController.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockListBuilder.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\custom_block\CustomBlockListController.
+ * Contains \Drupal\custom_block\CustomBlockListBuilder.
  */
 
 namespace Drupal\custom_block;
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityListController;
+use Drupal\Core\Entity\EntityListBuilder;
 
 /**
  * Provides a listing of custom block entities.
  */
-class CustomBlockListController extends EntityListController {
+class CustomBlockListBuilder extends EntityListBuilder {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeListController.php b/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeListBuilder.php
similarity index 77%
rename from core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeListController.php
rename to core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeListBuilder.php
index 84a8ad9..9ae5408 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeListController.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeListBuilder.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\custom_block\CustomBlockTypeListController.
+ * Contains \Drupal\custom_block\CustomBlockTypeListBuilder.
  */
 
 namespace Drupal\custom_block;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of custom block types.
  */
-class CustomBlockTypeListController extends ConfigEntityListController {
+class CustomBlockTypeListBuilder extends ConfigEntityListBuilder {
 
   /**
    * {@inheritdoc}
@@ -29,7 +29,7 @@ public function getOperations(EntityInterface $entity) {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildHeader().
+   * {@inheritdoc}
    */
   public function buildHeader() {
     $header['type'] = t('Block type');
@@ -38,7 +38,7 @@ public function buildHeader() {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildRow().
+   * {@inheritdoc}
    */
   public function buildRow(EntityInterface $entity) {
     $uri = $entity->urlInfo();
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php b/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php
index 68c3b10..767793b 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php
@@ -22,7 +22,7 @@
  *   controllers = {
  *     "storage" = "Drupal\Core\Entity\FieldableDatabaseStorageController",
  *     "access" = "Drupal\custom_block\CustomBlockAccessController",
- *     "list" = "Drupal\custom_block\CustomBlockListController",
+ *     "list" = "Drupal\custom_block\CustomBlockListBuilder",
  *     "view_builder" = "Drupal\custom_block\CustomBlockViewBuilder",
  *     "form" = {
  *       "add" = "Drupal\custom_block\CustomBlockFormController",
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlockType.php b/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlockType.php
index 0b41a4d..5553c64 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlockType.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlockType.php
@@ -25,7 +25,7 @@
  *       "edit" = "Drupal\custom_block\CustomBlockTypeFormController",
  *       "delete" = "Drupal\custom_block\Form\CustomBlockTypeDeleteForm"
  *     },
- *     "list" = "Drupal\custom_block\CustomBlockTypeListController"
+ *     "list" = "Drupal\custom_block\CustomBlockTypeListBuilder"
  *   },
  *   admin_permission = "administer blocks",
  *   config_prefix = "custom_block.type",
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/Tests/CustomBlockListTest.php b/core/modules/block/custom_block/lib/Drupal/custom_block/Tests/CustomBlockListTest.php
index 3678a23..fa7cc8f 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/Tests/CustomBlockListTest.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/Tests/CustomBlockListTest.php
@@ -12,7 +12,7 @@
 /**
  * Tests the listing of custom blocks.
  *
- * @see \Drupal\block\CustomBlockListController
+ * @see \Drupal\block\CustomBlockListBuilder
  */
 class CustomBlockListTest extends WebTestBase {
 
diff --git a/core/modules/block/lib/Drupal/block/Controller/BlockListController.php b/core/modules/block/lib/Drupal/block/Controller/BlockListController.php
index 2852970..72aa445 100644
--- a/core/modules/block/lib/Drupal/block/Controller/BlockListController.php
+++ b/core/modules/block/lib/Drupal/block/Controller/BlockListController.php
@@ -8,7 +8,6 @@
 namespace Drupal\block\Controller;
 
 use Drupal\Core\Entity\Controller\EntityListController;
-use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\Request;
 
 /**
@@ -29,7 +28,7 @@ class BlockListController extends EntityListController {
    */
   public function listing($theme = NULL, Request $request = NULL) {
     $theme = $theme ?: $this->config('system.theme')->get('default');
-    return $this->entityManager()->getListController('block')->render($theme, $request);
+    return $this->entityManager()->getListBuilder('block')->render($theme, $request);
   }
 
 }
diff --git a/core/modules/block/lib/Drupal/block/Entity/Block.php b/core/modules/block/lib/Drupal/block/Entity/Block.php
index dc20929..9d5e4e7 100644
--- a/core/modules/block/lib/Drupal/block/Entity/Block.php
+++ b/core/modules/block/lib/Drupal/block/Entity/Block.php
@@ -22,7 +22,7 @@
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
  *     "access" = "Drupal\block\BlockAccessController",
  *     "view_builder" = "Drupal\block\BlockViewBuilder",
- *     "list" = "Drupal\block\BlockListController",
+ *     "list" = "Drupal\block\BlockListBuilder",
  *     "form" = {
  *       "default" = "Drupal\block\BlockFormController",
  *       "delete" = "Drupal\block\Form\BlockDeleteForm"
diff --git a/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigQueryTest.php b/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigQueryTest.php
index c781d22..15448c0 100644
--- a/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigQueryTest.php
+++ b/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigQueryTest.php
@@ -15,7 +15,7 @@
  *   label = @Translation("Test configuration for query"),
  *   controllers = {
  *     "storage" = "Drupal\config_test\ConfigTestStorageController",
- *     "list" = "Drupal\Core\Config\Entity\ConfigEntityListController",
+ *     "list" = "Drupal\Core\Config\Entity\ConfigEntityListBuilder",
  *     "form" = {
  *       "default" = "Drupal\config_test\ConfigTestFormController"
  *     }
diff --git a/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigTest.php b/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigTest.php
index 623fa14..9ceb55e 100644
--- a/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigTest.php
+++ b/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigTest.php
@@ -18,7 +18,7 @@
  *   label = @Translation("Test configuration"),
  *   controllers = {
  *     "storage" = "Drupal\config_test\ConfigTestStorageController",
- *     "list" = "Drupal\config_test\ConfigTestListController",
+ *     "list" = "Drupal\config_test\ConfigTestListBuilder",
  *     "form" = {
  *       "default" = "Drupal\config_test\ConfigTestFormController",
  *       "delete" = "Drupal\config_test\Form\ConfigTestDeleteForm"
diff --git a/core/modules/config_translation/config_translation.module b/core/modules/config_translation/config_translation.module
index e3f1ac9..9e7c6c9 100644
--- a/core/modules/config_translation/config_translation.module
+++ b/core/modules/config_translation/config_translation.module
@@ -91,13 +91,13 @@ function config_translation_entity_info($entity_info) {
   /** @var $entity_info \Drupal\Core\Entity\EntityTypeInterface[] */
   foreach ($entity_info as $entity_type_id => $entity_type) {
     if ($entity_type_id == 'block') {
-      $class = 'Drupal\config_translation\Controller\ConfigTranslationBlockListController';
+      $class = 'Drupal\config_translation\Controller\ConfigTranslationBlockListBuilder';
     }
     elseif ($entity_type_id == 'field_instance') {
-      $class = 'Drupal\config_translation\Controller\ConfigTranslationFieldInstanceListController';
+      $class = 'Drupal\config_translation\Controller\ConfigTranslationFieldInstanceListBuilder';
     }
     else {
-      $class = 'Drupal\config_translation\Controller\ConfigTranslationEntityListController';
+      $class = 'Drupal\config_translation\Controller\ConfigTranslationEntityListBuilder';
     }
     $entity_type->setControllerClass('config_translation_list', $class);
   }
diff --git a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListControllerInterface.php b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListBuilderInterface.php
similarity index 78%
rename from core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListControllerInterface.php
rename to core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListBuilderInterface.php
index f2340b3..08791c8 100644
--- a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListControllerInterface.php
+++ b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListBuilderInterface.php
@@ -2,17 +2,17 @@
 
 /**
  * @file
- * Contains \Drupal\config_translation\Controller\ConfigTranslationEntityListControllerInterface.
+ * Contains \Drupal\config_translation\Controller\ConfigTranslationEntityListBuilderInterface.
  */
 
 namespace Drupal\config_translation\Controller;
 
-use Drupal\Core\Entity\EntityListControllerInterface;
+use Drupal\Core\Entity\EntityListBuilderInterface;
 
 /**
- * Defines an interface for configuration translation entity list controllers.
+ * Defines an interface for configuration translation entity list builders.
  */
-interface ConfigTranslationEntityListControllerInterface extends EntityListControllerInterface {
+interface ConfigTranslationEntityListBuilderInterface extends EntityListBuilderInterface {
 
   /**
    * Sorts an array by value.
diff --git a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationMapperList.php b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationMapperList.php
index 8b7f63f..fa4ba4a 100644
--- a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationMapperList.php
+++ b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationMapperList.php
@@ -120,7 +120,7 @@ public function buildHeader() {
    * @return array
    *   A renderable array of operation links.
    *
-   * @see \Drupal\Core\Entity\EntityListController::buildOperations()
+   * @see \Drupal\Core\Entity\EntityList::buildOperations()
    */
   protected function buildOperations(ConfigMapperInterface $mapper) {
     // Retrieve and sort operations.
diff --git a/core/modules/contact/lib/Drupal/contact/CategoryListController.php b/core/modules/contact/lib/Drupal/contact/CategoryListBuilder.php
similarity index 75%
rename from core/modules/contact/lib/Drupal/contact/CategoryListController.php
rename to core/modules/contact/lib/Drupal/contact/CategoryListBuilder.php
index 1e62630..7b5a3d2 100644
--- a/core/modules/contact/lib/Drupal/contact/CategoryListController.php
+++ b/core/modules/contact/lib/Drupal/contact/CategoryListBuilder.php
@@ -1,21 +1,22 @@
 <?php
 
 /**
- * Definition of Drupal\contact\CategoryListController.
+ * @file
+ * Contains \Drupal\contact\CategoryListBuilder.
  */
 
 namespace Drupal\contact;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of contact categories.
  */
-class CategoryListController extends ConfigEntityListController {
+class CategoryListBuilder extends ConfigEntityListBuilder {
 
   /**
-   * Overrides Drupal\Core\Entity\EntityListController::buildHeader().
+   * {@inheritdoc}
    */
   public function buildHeader() {
     $header['category'] = t('Category');
@@ -25,7 +26,7 @@ public function buildHeader() {
   }
 
   /**
-   * Overrides Drupal\Core\Entity\EntityListController::buildRow().
+   * {@inheritdoc}
    */
   public function buildRow(EntityInterface $entity) {
     $row['category'] = $this->getLabel($entity);
diff --git a/core/modules/contact/lib/Drupal/contact/Entity/Category.php b/core/modules/contact/lib/Drupal/contact/Entity/Category.php
index a3d3187..d8ad6ef 100644
--- a/core/modules/contact/lib/Drupal/contact/Entity/Category.php
+++ b/core/modules/contact/lib/Drupal/contact/Entity/Category.php
@@ -20,7 +20,7 @@
  *   controllers = {
  *     "storage" = "Drupal\contact\CategoryStorageController",
  *     "access" = "Drupal\contact\CategoryAccessController",
- *     "list" = "Drupal\contact\CategoryListController",
+ *     "list" = "Drupal\contact\CategoryListBuilder",
  *     "form" = {
  *       "add" = "Drupal\contact\CategoryFormController",
  *       "edit" = "Drupal\contact\CategoryFormController",
diff --git a/core/modules/entity/lib/Drupal/entity/Entity/EntityFormMode.php b/core/modules/entity/lib/Drupal/entity/Entity/EntityFormMode.php
index 43bdad1..eeb39d6 100644
--- a/core/modules/entity/lib/Drupal/entity/Entity/EntityFormMode.php
+++ b/core/modules/entity/lib/Drupal/entity/Entity/EntityFormMode.php
@@ -31,7 +31,7 @@
  *   id = "form_mode",
  *   label = @Translation("Form mode"),
  *   controllers = {
- *     "list" = "Drupal\entity\EntityFormModeListController",
+ *     "list" = "Drupal\entity\EntityFormModeListBuilder",
  *     "form" = {
  *       "add" = "Drupal\entity\Form\EntityFormModeAddForm",
  *       "edit" = "Drupal\entity\Form\EntityDisplayModeEditForm",
diff --git a/core/modules/entity/lib/Drupal/entity/Entity/EntityViewMode.php b/core/modules/entity/lib/Drupal/entity/Entity/EntityViewMode.php
index 9a31767..15ae592 100644
--- a/core/modules/entity/lib/Drupal/entity/Entity/EntityViewMode.php
+++ b/core/modules/entity/lib/Drupal/entity/Entity/EntityViewMode.php
@@ -32,7 +32,7 @@
  *   id = "view_mode",
  *   label = @Translation("View mode"),
  *   controllers = {
- *     "list" = "Drupal\entity\EntityDisplayModeListController",
+ *     "list" = "Drupal\entity\EntityDisplayModeListBuilder",
  *     "form" = {
  *       "add" = "Drupal\entity\Form\EntityDisplayModeAddForm",
  *       "edit" = "Drupal\entity\Form\EntityDisplayModeEditForm",
diff --git a/core/modules/entity/lib/Drupal/entity/EntityFormModeListController.php b/core/modules/entity/lib/Drupal/entity/EntityFormModeListBuilder.php
similarity index 78%
rename from core/modules/entity/lib/Drupal/entity/EntityFormModeListController.php
rename to core/modules/entity/lib/Drupal/entity/EntityFormModeListBuilder.php
index 04bc923..ebda019 100644
--- a/core/modules/entity/lib/Drupal/entity/EntityFormModeListController.php
+++ b/core/modules/entity/lib/Drupal/entity/EntityFormModeListBuilder.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\entity\EntityFormModeListController.
+ * Contains \Drupal\entity\EntityFormModeListBuilder.
  */
 
 namespace Drupal\entity;
@@ -10,7 +10,7 @@
 /**
  * Provides the listing for entity display modes.
  */
-class EntityFormModeListController extends EntityDisplayModeListController {
+class EntityFormModeListBuilder extends EntityDisplayModeListBuilder {
 
   /**
    * Filters entities based on their controllers.
diff --git a/core/modules/field_ui/field_ui.module b/core/modules/field_ui/field_ui.module
index bb8ec0b..c8066d9 100644
--- a/core/modules/field_ui/field_ui.module
+++ b/core/modules/field_ui/field_ui.module
@@ -135,7 +135,7 @@ function field_ui_element_info() {
 function field_ui_entity_info(&$entity_info) {
   /** @var $entity_info \Drupal\Core\Entity\EntityTypeInterface[] */
   $entity_info['field_instance']->setFormClass('delete', 'Drupal\field_ui\Form\FieldDeleteForm');
-  $entity_info['field_entity']->setListClass('Drupal\field_ui\FieldListController');
+  $entity_info['field_entity']->setListClass('Drupal\field_ui\FieldList');
 
   foreach ($entity_info as $info) {
     if ($bundle = $info->getBundleOf()) {
diff --git a/core/modules/filter/lib/Drupal/filter/Entity/FilterFormat.php b/core/modules/filter/lib/Drupal/filter/Entity/FilterFormat.php
index fb6292b..5d66afb 100644
--- a/core/modules/filter/lib/Drupal/filter/Entity/FilterFormat.php
+++ b/core/modules/filter/lib/Drupal/filter/Entity/FilterFormat.php
@@ -25,7 +25,7 @@
  *       "edit" = "Drupal\filter\FilterFormatEditFormController",
  *       "disable" = "Drupal\filter\Form\FilterDisableForm"
  *     },
- *     "list" = "Drupal\filter\FilterFormatListController",
+ *     "list" = "Drupal\filter\FilterFormatListBuilder",
  *     "access" = "Drupal\filter\FilterFormatAccessController",
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController"
  *   },
diff --git a/core/modules/image/lib/Drupal/image/Entity/ImageStyle.php b/core/modules/image/lib/Drupal/image/Entity/ImageStyle.php
index 506f660..6a270e6 100644
--- a/core/modules/image/lib/Drupal/image/Entity/ImageStyle.php
+++ b/core/modules/image/lib/Drupal/image/Entity/ImageStyle.php
@@ -30,7 +30,7 @@
  *       "flush" = "Drupal\image\Form\ImageStyleFlushForm"
  *     },
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
- *     "list" = "Drupal\image\ImageStyleListController",
+ *     "list" = "Drupal\image\ImageStyleListBuilder",
  *   },
  *   admin_permission = "administer image styles",
  *   config_prefix = "image.style",
diff --git a/core/modules/language/lib/Drupal/language/Entity/Language.php b/core/modules/language/lib/Drupal/language/Entity/Language.php
index 63e8542..a9768f9 100644
--- a/core/modules/language/lib/Drupal/language/Entity/Language.php
+++ b/core/modules/language/lib/Drupal/language/Entity/Language.php
@@ -20,7 +20,7 @@
  *   label = @Translation("Language"),
  *   controllers = {
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
- *     "list" = "Drupal\language\LanguageListController",
+ *     "list" = "Drupal\language\LanguageListBuilder",
  *     "access" = "Drupal\language\LanguageAccessController",
  *     "form" = {
  *       "add" = "Drupal\language\Form\LanguageAddForm",
diff --git a/core/modules/language/lib/Drupal/language/LanguageListController.php b/core/modules/language/lib/Drupal/language/LanguageListBuilder.php
similarity index 92%
rename from core/modules/language/lib/Drupal/language/LanguageListController.php
rename to core/modules/language/lib/Drupal/language/LanguageListBuilder.php
index da1454f..5d29b82 100644
--- a/core/modules/language/lib/Drupal/language/LanguageListController.php
+++ b/core/modules/language/lib/Drupal/language/LanguageListBuilder.php
@@ -1,18 +1,19 @@
 <?php
+
 /**
  * @file
- * Contains \Drupal\language\Form\LanguageListController.
+ * Contains \Drupal\language\Form\LanguageListBuilder.
  */
 
 namespace Drupal\language;
 
-use Drupal\Core\Config\Entity\DraggableListController;
+use Drupal\Core\Config\Entity\DraggableListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * User interface for the language overview screen.
  */
-class LanguageListController extends DraggableListController {
+class LanguageListBuilder extends DraggableListBuilder {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/menu/lib/Drupal/menu/MenuListController.php b/core/modules/menu/lib/Drupal/menu/MenuListBuilder.php
similarity index 78%
rename from core/modules/menu/lib/Drupal/menu/MenuListController.php
rename to core/modules/menu/lib/Drupal/menu/MenuListBuilder.php
index 18a3732..655ee20 100644
--- a/core/modules/menu/lib/Drupal/menu/MenuListController.php
+++ b/core/modules/menu/lib/Drupal/menu/MenuListBuilder.php
@@ -1,21 +1,22 @@
 <?php
 
 /**
- * Contains \Drupal\menu\MenuListController.
+ * @file
+ * Contains \Drupal\menu\MenuListBuilder.
  */
 
 namespace Drupal\menu;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of menus.
  */
-class MenuListController extends ConfigEntityListController {
+class MenuListBuilder extends ConfigEntityListBuilder {
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildHeader().
+   * {@inheritdoc}
    */
   public function buildHeader() {
     $header['title'] = t('Title');
@@ -27,7 +28,7 @@ public function buildHeader() {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildRow().
+   * {@inheritdoc}
    */
   public function buildRow(EntityInterface $entity) {
     $row['title'] = array(
@@ -58,7 +59,7 @@ public function getOperations(EntityInterface $entity) {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::render();
+   * {@inheritdoc}
    */
   public function render() {
     $build = parent::render();
diff --git a/core/modules/menu/menu.module b/core/modules/menu/menu.module
index 64a171b..cc91ace 100644
--- a/core/modules/menu/menu.module
+++ b/core/modules/menu/menu.module
@@ -114,7 +114,7 @@ function menu_entity_info(&$entity_info) {
     ->setFormClass('add', 'Drupal\menu\MenuFormController')
     ->setFormClass('edit', 'Drupal\menu\MenuFormController')
     ->setFormClass('delete', 'Drupal\menu\Form\MenuDeleteForm')
-    ->setListClass('Drupal\menu\MenuListController')
+    ->setListClass('Drupal\menu\MenuListBuilder')
     ->setLinkTemplate('add-form', 'menu.link_add')
     ->setLinkTemplate('delete-form', 'menu.delete_menu')
     ->setLinkTemplate('edit-form', 'menu.menu_edit');
diff --git a/core/modules/migrate/lib/Drupal/migrate/Entity/Migration.php b/core/modules/migrate/lib/Drupal/migrate/Entity/Migration.php
index e572bed..e1ef0d7 100644
--- a/core/modules/migrate/lib/Drupal/migrate/Entity/Migration.php
+++ b/core/modules/migrate/lib/Drupal/migrate/Entity/Migration.php
@@ -23,7 +23,7 @@
  *   module = "migrate",
  *   controllers = {
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
- *     "list" = "Drupal\Core\Config\Entity\DraggableListController",
+ *     "list" = "Drupal\Core\Config\Entity\DraggableListBuilder",
  *     "access" = "Drupal\Core\Entity\EntityAccessController",
  *     "form" = {
  *       "add" = "Drupal\Core\Entity\EntityFormController",
diff --git a/core/modules/node/lib/Drupal/node/Entity/Node.php b/core/modules/node/lib/Drupal/node/Entity/Node.php
index ec3533a..d0decce 100644
--- a/core/modules/node/lib/Drupal/node/Entity/Node.php
+++ b/core/modules/node/lib/Drupal/node/Entity/Node.php
@@ -30,7 +30,7 @@
  *       "delete" = "Drupal\node\Form\NodeDeleteForm",
  *       "edit" = "Drupal\node\NodeFormController"
  *     },
- *     "list" = "Drupal\node\NodeListController",
+ *     "list" = "Drupal\node\NodeListBuilder",
  *     "translation" = "Drupal\node\NodeTranslationController"
  *   },
  *   base_table = "node",
diff --git a/core/modules/node/lib/Drupal/node/Entity/NodeType.php b/core/modules/node/lib/Drupal/node/Entity/NodeType.php
index 2b36eb5..3ebe6cf 100644
--- a/core/modules/node/lib/Drupal/node/Entity/NodeType.php
+++ b/core/modules/node/lib/Drupal/node/Entity/NodeType.php
@@ -27,7 +27,7 @@
  *       "edit" = "Drupal\node\NodeTypeFormController",
  *       "delete" = "Drupal\node\Form\NodeTypeDeleteConfirm"
  *     },
- *     "list" = "Drupal\node\NodeTypeListController",
+ *     "list" = "Drupal\node\NodeTypeListBuilder",
  *   },
  *   admin_permission = "administer content types",
  *   config_prefix = "node.type",
diff --git a/core/modules/node/lib/Drupal/node/NodeTypeListController.php b/core/modules/node/lib/Drupal/node/NodeTypeListBuilder.php
similarity index 91%
rename from core/modules/node/lib/Drupal/node/NodeTypeListController.php
rename to core/modules/node/lib/Drupal/node/NodeTypeListBuilder.php
index 1549b8f..1c0730a 100644
--- a/core/modules/node/lib/Drupal/node/NodeTypeListController.php
+++ b/core/modules/node/lib/Drupal/node/NodeTypeListBuilder.php
@@ -1,13 +1,13 @@
 <?php
 
 /**
- * Contains \Drupal\node\NodeTypeListController.
+ * @file
+ * Contains \Drupal\node\NodeTypeListBuilder.
  */
 
 namespace Drupal\node;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
-use Drupal\Core\Entity\EntityControllerInterface;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityTypeInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
@@ -19,7 +19,7 @@
 /**
  * Provides a listing of node types.
  */
-class NodeTypeListController extends ConfigEntityListController implements EntityControllerInterface {
+class NodeTypeListBuilder extends ConfigEntityListBuilder {
 
   /**
    * The url generator service.
diff --git a/core/modules/picture/lib/Drupal/picture/Entity/PictureMapping.php b/core/modules/picture/lib/Drupal/picture/Entity/PictureMapping.php
index 05ff927..2f789e7 100644
--- a/core/modules/picture/lib/Drupal/picture/Entity/PictureMapping.php
+++ b/core/modules/picture/lib/Drupal/picture/Entity/PictureMapping.php
@@ -18,7 +18,7 @@
  *   label = @Translation("Picture mapping"),
  *   controllers = {
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
- *     "list" = "Drupal\picture\PictureMappingListController",
+ *     "list" = "Drupal\picture\PictureMappingListBuilder",
  *     "form" = {
  *       "edit" = "Drupal\picture\PictureMappingFormController",
  *       "add" = "Drupal\picture\PictureMappingFormController",
diff --git a/core/modules/picture/lib/Drupal/picture/PictureMappingListController.php b/core/modules/picture/lib/Drupal/picture/PictureMappingListBuilder.php
similarity index 82%
rename from core/modules/picture/lib/Drupal/picture/PictureMappingListController.php
rename to core/modules/picture/lib/Drupal/picture/PictureMappingListBuilder.php
index e391676..42930db 100644
--- a/core/modules/picture/lib/Drupal/picture/PictureMappingListController.php
+++ b/core/modules/picture/lib/Drupal/picture/PictureMappingListBuilder.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains Drupal\picture\PictureListController.
+ * Contains \Drupal\picture\PictureMappingListBuilder.
  */
 
 namespace Drupal\picture;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of Pictures.
  */
-class PictureMappingListController extends ConfigEntityListController {
+class PictureMappingListBuilder extends ConfigEntityListBuilder {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/search/lib/Drupal/search/Entity/SearchPage.php b/core/modules/search/lib/Drupal/search/Entity/SearchPage.php
index 1baa4f6..f204efa 100644
--- a/core/modules/search/lib/Drupal/search/Entity/SearchPage.php
+++ b/core/modules/search/lib/Drupal/search/Entity/SearchPage.php
@@ -23,7 +23,7 @@
  *   controllers = {
  *     "access" = "Drupal\search\SearchPageAccessController",
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
- *     "list" = "Drupal\search\SearchPageListController",
+ *     "list" = "Drupal\search\SearchPageListBuilder",
  *     "form" = {
  *       "add" = "Drupal\search\Form\SearchPageAddForm",
  *       "edit" = "Drupal\search\Form\SearchPageEditForm",
diff --git a/core/modules/shortcut/lib/Drupal/shortcut/Entity/ShortcutSet.php b/core/modules/shortcut/lib/Drupal/shortcut/Entity/ShortcutSet.php
index c9dee35..1d67150 100644
--- a/core/modules/shortcut/lib/Drupal/shortcut/Entity/ShortcutSet.php
+++ b/core/modules/shortcut/lib/Drupal/shortcut/Entity/ShortcutSet.php
@@ -21,7 +21,7 @@
  *   controllers = {
  *     "storage" = "Drupal\shortcut\ShortcutSetStorageController",
  *     "access" = "Drupal\shortcut\ShortcutSetAccessController",
- *     "list" = "Drupal\shortcut\ShortcutSetListController",
+ *     "list" = "Drupal\shortcut\ShortcutSetListBuilder",
  *     "form" = {
  *       "default" = "Drupal\shortcut\ShortcutSetFormController",
  *       "add" = "Drupal\shortcut\ShortcutSetFormController",
diff --git a/core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetListController.php b/core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetListBuilder.php
similarity index 71%
rename from core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetListController.php
rename to core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetListBuilder.php
index 6741ed2..010dd1b 100644
--- a/core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetListController.php
+++ b/core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetListBuilder.php
@@ -2,21 +2,21 @@
 
 /**
  * @file
- * Contains \Drupal\shortcut\ShortcutSetListController.
+ * Contains \Drupal\shortcut\ShortcutSetListBuilder.
  */
 
 namespace Drupal\shortcut;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of shortcut sets.
  */
-class ShortcutSetListController extends ConfigEntityListController {
+class ShortcutSetListBuilder extends ConfigEntityListBuilder {
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildHeader().
+   * {@inheritdoc}
    */
   public function buildHeader() {
     $header['name'] = t('Name');
@@ -40,7 +40,7 @@ public function getOperations(EntityInterface $entity) {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildRow().
+   * {@inheritdoc}
    */
   public function buildRow(EntityInterface $entity) {
     $row['name'] = $this->getLabel($entity);
diff --git a/core/modules/system/entity.api.php b/core/modules/system/entity.api.php
index 4ea960c..ab9e605 100644
--- a/core/modules/system/entity.api.php
+++ b/core/modules/system/entity.api.php
@@ -694,7 +694,7 @@ function hook_entity_field_info_alter(&$info, $entity_type) {
  *
  * @param array $operations
  *   Operations array as returned by
- *   \Drupal\Core\Entity\EntityListControllerInterface::getOperations().
+ *   \Drupal\Core\Entity\EntityListBuilderInterface::getOperations().
  * @param \Drupal\Core\Entity\EntityInterface $entity
  *   The entity on which the linked operations will be performed.
  */
diff --git a/core/modules/system/lib/Drupal/system/Entity/DateFormat.php b/core/modules/system/lib/Drupal/system/Entity/DateFormat.php
index 8dbdf5b..efa1ff7 100644
--- a/core/modules/system/lib/Drupal/system/Entity/DateFormat.php
+++ b/core/modules/system/lib/Drupal/system/Entity/DateFormat.php
@@ -21,7 +21,7 @@
  *   controllers = {
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
  *     "access" = "Drupal\system\DateFormatAccessController",
- *     "list" = "Drupal\system\DateFormatListController",
+ *     "list" = "Drupal\system\DateFormatListBuilder",
  *     "form" = {
  *       "add" = "Drupal\system\Form\DateFormatAddForm",
  *       "edit" = "Drupal\system\Form\DateFormatEditForm",
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php
index b7f799c..d174e6d 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php
@@ -20,7 +20,7 @@
  *   label = @Translation("Test entity"),
  *   controllers = {
  *     "storage" = "Drupal\Core\Entity\FieldableDatabaseStorageController",
- *     "list" = "Drupal\entity_test\EntityTestListController",
+ *     "list" = "Drupal\entity_test\EntityTestListBuilder",
  *     "view_builder" = "Drupal\entity_test\EntityTestViewBuilder",
  *     "access" = "Drupal\entity_test\EntityTestAccessController",
  *     "form" = {
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Vocabulary.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Vocabulary.php
index 7857c07..c02fd0d 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Vocabulary.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Vocabulary.php
@@ -19,7 +19,7 @@
  *   label = @Translation("Taxonomy vocabulary"),
  *   controllers = {
  *     "storage" = "Drupal\taxonomy\VocabularyStorageController",
- *     "list" = "Drupal\taxonomy\VocabularyListController",
+ *     "list" = "Drupal\taxonomy\VocabularyListBuilder",
  *     "form" = {
  *       "default" = "Drupal\taxonomy\VocabularyFormController",
  *       "reset" = "Drupal\taxonomy\Form\VocabularyResetForm",
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyListController.php b/core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyListBuilder.php
similarity index 92%
rename from core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyListController.php
rename to core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyListBuilder.php
index 104b360..7b7600d 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyListController.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyListBuilder.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\taxonomy\VocabularyListController.
+ * Contains \Drupal\taxonomy\VocabularyListBuilder.
  */
 
 namespace Drupal\taxonomy;
 
-use Drupal\Core\Config\Entity\DraggableListController;
+use Drupal\Core\Config\Entity\DraggableListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of vocabularies.
  */
-class VocabularyListController extends DraggableListController {
+class VocabularyListBuilder extends DraggableListBuilder {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/user/lib/Drupal/user/Entity/Role.php b/core/modules/user/lib/Drupal/user/Entity/Role.php
index e4b5f04..08b2dd7 100644
--- a/core/modules/user/lib/Drupal/user/Entity/Role.php
+++ b/core/modules/user/lib/Drupal/user/Entity/Role.php
@@ -21,7 +21,7 @@
  *   controllers = {
  *     "storage" = "Drupal\user\RoleStorageController",
  *     "access" = "Drupal\user\RoleAccessController",
- *     "list" = "Drupal\user\RoleListController",
+ *     "list" = "Drupal\user\RoleListBuilder",
  *     "form" = {
  *       "default" = "Drupal\user\RoleFormController",
  *       "delete" = "Drupal\user\Form\UserRoleDelete"
diff --git a/core/modules/user/lib/Drupal/user/Entity/User.php b/core/modules/user/lib/Drupal/user/Entity/User.php
index f9db482..a9f5ead 100644
--- a/core/modules/user/lib/Drupal/user/Entity/User.php
+++ b/core/modules/user/lib/Drupal/user/Entity/User.php
@@ -22,7 +22,7 @@
  *   controllers = {
  *     "storage" = "Drupal\user\UserStorageController",
  *     "access" = "Drupal\user\UserAccessController",
- *     "list" = "Drupal\user\Controller\UserListController",
+ *     "list" = "Drupal\user\UserListBuilder",
  *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
  *     "form" = {
  *       "default" = "Drupal\user\ProfileFormController",
diff --git a/core/modules/user/lib/Drupal/user/RoleListController.php b/core/modules/user/lib/Drupal/user/RoleListBuilder.php
similarity index 88%
rename from core/modules/user/lib/Drupal/user/RoleListController.php
rename to core/modules/user/lib/Drupal/user/RoleListBuilder.php
index c2cd9b9..1e39f3b 100644
--- a/core/modules/user/lib/Drupal/user/RoleListController.php
+++ b/core/modules/user/lib/Drupal/user/RoleListBuilder.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\user\RoleListController.
+ * Contains \Drupal\user\RoleListBuilder.
  */
 
 namespace Drupal\user;
 
-use Drupal\Core\Config\Entity\DraggableListController;
+use Drupal\Core\Config\Entity\DraggableListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of user roles.
  */
-class RoleListController extends DraggableListController {
+class RoleListBuilder extends DraggableListBuilder {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php b/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
index 1e3575d..7f8ea25 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
@@ -164,7 +164,7 @@ public function ajaxOperation(ViewStorageInterface $view, $op, Request $request)
 
     // If the request is via AJAX, return the rendered list as JSON.
     if ($request->request->get('js')) {
-      $list = $this->entityManager->getListController('view')->render();
+      $list = $this->entityManager->getListBuilder('view')->render();
       $response = new AjaxResponse();
       $response->addCommand(new ReplaceCommand('#views-entity-list', drupal_render($list)));
       return $response;
diff --git a/core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListControllerTest.php b/core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListBuilderTest.php
similarity index 88%
rename from core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListControllerTest.php
rename to core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListBuilderTest.php
index 534f824..fdc3b42 100644
--- a/core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListControllerTest.php
+++ b/core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListBuilderTest.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\views_ui\Tests\ViewListControllerTest
+ * Contains \Drupal\views_ui\Tests\ViewListBuilderTest.
  */
 
 namespace Drupal\views_ui\Tests;
@@ -12,14 +12,14 @@
 use Drupal\Tests\UnitTestCase;
 use Drupal\views\Entity\View;
 use Drupal\views\ViewExecutableFactory;
-use Drupal\views_ui\ViewListController;
+use Drupal\views_ui\ViewListBuilder;
 
-class ViewListControllerTest extends UnitTestCase {
+class ViewListBuilderTest extends UnitTestCase {
 
   public static function getInfo() {
     return array(
       'name' => 'Views List Controller Unit Test',
-      'description' => 'Unit tests the views list controller',
+      'description' => 'Unit tests the views list',
       'group' => 'Views UI',
     );
   }
@@ -27,7 +27,7 @@ public static function getInfo() {
   /**
    * Tests the listing of displays on a views list.
    *
-   * @see \Drupal\views_ui\ViewListController::getDisplaysList().
+   * @see \Drupal\views_ui\ViewList::getDisplaysList()
    */
   public function testBuildRowEntityList() {
     $storage_controller = $this->getMockBuilder('Drupal\views\ViewStorageController')
@@ -124,12 +124,12 @@ public function testBuildRowEntityList() {
     // Setup a view list controller with a mocked buildOperations method,
     // because t() is called on there.
     $entity_type = $this->getMock('Drupal\Core\Entity\EntityTypeInterface');
-    $view_list_controller = new TestViewListController($entity_type, $storage_controller, $display_manager);
-    $view_list_controller->setTranslationManager($this->getStringTranslationStub());
+    $view_list = new TestViewListBuilder($entity_type, $storage_controller, $display_manager);
+    $view_list->setTranslationManager($this->getStringTranslationStub());
 
     $view = new View($values, 'view');
 
-    $row = $view_list_controller->buildRow($view);
+    $row = $view_list->buildRow($view);
 
     $this->assertEquals(array('Embed admin label', 'Page admin label'), $row['data']['view_name']['data']['#displays'], 'Wrong displays got added to view list');
     $this->assertEquals($row['data']['path'], '/test_page', 'The path of the page display is not added.');
@@ -137,7 +137,7 @@ public function testBuildRowEntityList() {
 
 }
 
-class TestViewListController extends ViewListController {
+class TestViewListBuilder extends ViewListBuilder {
 
   public function buildOperations(EntityInterface $entity) {
     return array();
diff --git a/core/modules/views_ui/views_ui.module b/core/modules/views_ui/views_ui.module
index 2cc12df..2d460fb 100644
--- a/core/modules/views_ui/views_ui.module
+++ b/core/modules/views_ui/views_ui.module
@@ -97,7 +97,7 @@ function views_ui_entity_info(&$entity_info) {
     ->setFormClass('clone', 'Drupal\views_ui\ViewCloneFormController')
     ->setFormClass('delete', 'Drupal\views_ui\ViewDeleteFormController')
     ->setFormClass('break_lock', 'Drupal\views_ui\Form\BreakLockForm')
-    ->setListClass('Drupal\views_ui\ViewListController')
+    ->setListClass('Drupal\views_ui\ViewList')
     ->setLinkTemplate('edit-form', 'views_ui.edit')
     ->setLinkTemplate('edit-display-form', 'views_ui.edit_display')
     ->setLinkTemplate('preview-form', 'views_ui.preview')
diff --git a/core/lib/Drupal/Core/Config/Entity/DraggableListController.php b/core/lib/Drupal/Core/Config/Entity/DraggableListBuilder.php
similarity index 94%
rename from core/lib/Drupal/Core/Config/Entity/DraggableListController.php
rename to core/lib/Drupal/Core/Config/Entity/DraggableListBuilder.php
index d057bc9..12e63c0 100644
--- a/core/lib/Drupal/Core/Config/Entity/DraggableListController.php
+++ b/core/lib/Drupal/Core/Config/Entity/DraggableListBuilder.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains Drupal\Core\Config\Entity\DraggableListController.
+ * Contains \Drupal\Core\Config\Entity\DraggableListBuilder.
  */
 
 namespace Drupal\Core\Config\Entity;
@@ -13,9 +13,9 @@
 use Drupal\Core\Form\FormInterface;
 
 /**
  * Provides a list controller for draggable configuration entities.
  */
-abstract class DraggableListController extends ConfigEntityListController implements FormInterface {
+abstract class DraggableListBuilder extends ConfigEntityListBuilder implements FormInterface {
 
   /**
    * The key to use for the form element containing the entities.
@@ -13,9 +13,9 @@
 
 /**
- * Provides a list controller for draggable configuration entities.
+ * Provides a draggable list builder for configuration entities.
  */
diff --git a/core/lib/Drupal/Core/Entity/EntityListController.php b/core/lib/Drupal/Core/Entity/EntityListBuilder.php
similarity index 85%
rename from core/lib/Drupal/Core/Entity/EntityListController.php
rename to core/lib/Drupal/Core/Entity/EntityListBuilder.php
index c56b229..4660838 100644
--- a/core/lib/Drupal/Core/Entity/EntityListController.php
+++ b/core/lib/Drupal/Core/Entity/EntityListBuilder.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\Core\Entity\EntityListController.
+ * Contains \Drupal\Core\Entity\EntityListBuilder.
  */
 
 namespace Drupal\Core\Entity;
@@ -13,9 +13,9 @@
 use Drupal\Component\Utility\String;
 
 /**
- * Provides a generic implementation of an entity list controller.
+ * Provides a generic implementation of an entity listing.
  */
-class EntityListController extends EntityControllerBase implements EntityListControllerInterface, EntityControllerInterface {
+class EntityListBuilder extends EntityControllerBase implements EntityListBuilderInterface, EntityControllerInterface {
 
   /**
    * The entity storage controller class.
@@ -49,7 +49,7 @@ public static function createInstance(ContainerInterface $container, EntityTypeI
   }
 
   /**
    * Constructs a new EntityListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -63,14 +63,14 @@ public function __construct(EntityTypeInterface $entity_info, EntityStorageContr
   }
 
   /**
-   * Implements \Drupal\Core\Entity\EntityListControllerInterface::getStorageController().
+   * {@inheritdoc}
    */
   public function getStorageController() {
     return $this->storage;
   }
 
   /**
-   * Implements \Drupal\Core\Entity\EntityListControllerInterface::load().
+   * {@inheritdoc}
    */
   public function load() {
     return $this->storage->loadMultiple();
@@ -116,7 +116,7 @@ public function getOperations(EntityInterface $entity) {
    * @return array
    *   A render array structure of header strings.
    *
-   * @see \Drupal\Core\Entity\EntityListController::render()
+   * @see \Drupal\Core\Entity\EntityListBuilder::render()
    */
   public function buildHeader() {
     $row['operations'] = $this->t('Operations');
@@ -132,7 +132,7 @@ public function buildHeader() {
    * @return array
    *   A render array structure of fields for this entity.
    *
-   * @see \Drupal\Core\Entity\EntityListController::render()
+   * @see \Drupal\Core\Entity\EntityListBuilder::render()
    */
   public function buildRow(EntityInterface $entity) {
     $row['operations']['data'] = $this->buildOperations($entity);
@@ -148,7 +148,7 @@ public function buildRow(EntityInterface $entity) {
    * @return array
    *   A renderable array of operation links.
    *
-   * @see \Drupal\Core\Entity\EntityListController::render()
+   * @see \Drupal\Core\Entity\EntityListBuilder::buildRow()
    */
   public function buildOperations(EntityInterface $entity) {
     // Retrieve and sort operations.
@@ -163,9 +163,9 @@ public function buildOperations(EntityInterface $entity) {
   }
 
   /**
-   * Implements \Drupal\Core\Entity\EntityListControllerInterface::render().
+   * {@inheritdoc}
    *
-   * Builds the entity list as renderable array for theme_table().
+   * Builds the entity listing as renderable array for theme_table().
    *
    * @todo Add a link to add a new item to the #empty text.
    */
@@ -199,7 +199,6 @@ protected function t($string, array $args = array(), array $options = array()) {
    *
    * @return string
    *   A string title of the page.
-   *
    */
   protected function getTitle() {
     return;
@@ -49,7 +49,7 @@ public static function createInstance(ContainerInterface $container, EntityTypeI
 
   /**
-   * Constructs a new EntityListController object.
+   * Constructs a new EntityListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/lib/Drupal/Core/Entity/EntityListControllerInterface.php b/core/lib/Drupal/Core/Entity/EntityListBuilderInterface.php
similarity index 68%
rename from core/lib/Drupal/Core/Entity/EntityListControllerInterface.php
rename to core/lib/Drupal/Core/Entity/EntityListBuilderInterface.php
index 775445e..99f5935 100644
--- a/core/lib/Drupal/Core/Entity/EntityListControllerInterface.php
+++ b/core/lib/Drupal/Core/Entity/EntityListBuilderInterface.php
@@ -2,32 +2,32 @@
 
 /**
  * @file
- * Contains \Drupal\Core\Entity\EntityListControllerInterface.
+ * Contains \Drupal\Core\Entity\EntityListBuilderInterface.
  */
 
 namespace Drupal\Core\Entity;
 
 /**
- * Defines an interface for entity list controllers.
+ * Defines an interface to build entity listings.
  */
-interface EntityListControllerInterface {
+interface EntityListBuilderInterface {
 
   /**
    * Gets the entity storage controller.
    *
    * @return \Drupal\Core\Entity\EntityStorageControllerInterface
    *   The storage controller used by this list controller.
    */
   public function getStorageController();
 
   /**
    * Loads entities of this type from storage for listing.
    *
-   * This allows the controller to manipulate the list, like filtering or
+   * This allows the implementation to manipulate the listing, like filtering or
    * sorting the loaded entities.
    *
    * @return \Drupal\Core\Entity\EntityInterface[]
-   *   An array of entities implementing Drupal\Core\Entity\EntityInterface.
+   *   An array of entities implementing \Drupal\Core\Entity\EntityInterface.
    */
   public function load();
 
@@ -48,10 +48,10 @@ public function load();
   public function getOperations(EntityInterface $entity);
 
   /**
-   * Renders the list page markup to be output.
+   * Returns a listing of entities for the given entity type.
    *
-   * @return string
-   *   The output markup for the listing page.
+   * @return array
+   *   A render array as expected by drupal_render().
    */
   public function render();
 
@@ -2,32 +2,32 @@
    *
    * @return \Drupal\Core\Entity\EntityStorageControllerInterface
-   *   The storage controller used by this list controller.
+   *   The storage controller used by this list builder.
    */
   public function getStorageController();
diff --git a/core/lib/Drupal/Core/Entity/EntityManagerInterface.php b/core/lib/Drupal/Core/Entity/EntityManagerInterface.php
index 35c7280..a4fc2d0 100644
--- a/core/lib/Drupal/Core/Entity/EntityManagerInterface.php
+++ b/core/lib/Drupal/Core/Entity/EntityManagerInterface.php
@@ -129,15 +129,15 @@ public function clearCachedDefinitions();
   public function getViewBuilder($entity_type);
 
   /**
    * Creates a new list controller instance.
    *
    * @param string $entity_type
    *   The entity type for this list controller.
    *
    * @return \Drupal\Core\Entity\EntityListControllerInterface
    *   A list controller instance.
    */
-  public function getListController($entity_type);
+  public function getListBuilder($entity_type);
 
   /**
    * Creates a new form controller instance.
@@ -129,15 +129,15 @@ public function clearCachedDefinitions();
 
   /**
-   * Creates a new list controller instance.
+   * Creates a new entity list builder.
    *
    * @param string $entity_type
@@ -129,15 +129,15 @@ public function clearCachedDefinitions();
    *
    * @param string $entity_type
-   *   The entity type for this list controller.
+   *   The entity type for this list builder.
    *
@@ -129,15 +129,15 @@ public function clearCachedDefinitions();
    *
-   * @return \Drupal\Core\Entity\EntityListControllerInterface
-   *   A list controller instance.
+   * @return \Drupal\Core\Entity\EntityListBuilderInterface
+   *   An entity list builder instance.
    */
diff --git a/core/modules/action/lib/Drupal/action/ActionListController.php b/core/modules/action/lib/Drupal/action/ActionListBuilder.php
similarity index 90%
rename from core/modules/action/lib/Drupal/action/ActionListController.php
rename to core/modules/action/lib/Drupal/action/ActionListBuilder.php
index ee612c9..d8e5d14 100644
--- a/core/modules/action/lib/Drupal/action/ActionListController.php
+++ b/core/modules/action/lib/Drupal/action/ActionListBuilder.php
@@ -2,15 +2,14 @@
 
 /**
  * @file
- * Contains \Drupal\action\ActionListController.
+ * Contains \Drupal\action\ActionListBuilder.
  */
 
 namespace Drupal\action;
 
 use Drupal\Core\Action\ActionManager;
-use Drupal\Core\Entity\EntityControllerInterface;
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
@@ -18,7 +17,7 @@
 /**
  * Provides a listing of Actions.
  */
-class ActionListController extends ConfigEntityListController implements EntityControllerInterface {
+class ActionListBuilder extends ConfigEntityListBuilder {
 
   /**
    * @var bool
@@ -33,7 +32,7 @@ class ActionListController extends ConfigEntityListController implements EntityC
   protected $actionManager;
 
   /**
    * Constructs a new ActionListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -33,7 +32,7 @@ class ActionListController extends ConfigEntityListController implements EntityC
 
   /**
-   * Constructs a new ActionListController object.
+   * Constructs a new ActionListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/modules/block/lib/Drupal/block/BlockListController.php b/core/modules/block/lib/Drupal/block/BlockListBuilder.php
similarity index 96%
rename from core/modules/block/lib/Drupal/block/BlockListController.php
rename to core/modules/block/lib/Drupal/block/BlockListBuilder.php
index 11503ed..d844903 100644
--- a/core/modules/block/lib/Drupal/block/BlockListController.php
+++ b/core/modules/block/lib/Drupal/block/BlockListBuilder.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\block\BlockListController.
+ * Contains \Drupal\block\BlockListBuilder.
  */
 
 namespace Drupal\block;
@@ -10,8 +10,7 @@
 use Drupal\Component\Plugin\PluginManagerInterface;
 use Drupal\Component\Utility\Json;
 use Drupal\Component\Utility\String;
-use Drupal\Core\Config\Entity\ConfigEntityListController;
-use Drupal\Core\Entity\EntityControllerInterface;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
@@ -21,9 +20,9 @@
 use Symfony\Component\HttpFoundation\Request;
 
 /**
  * Defines the block list controller.
  */
-class BlockListController extends ConfigEntityListController implements FormInterface, EntityControllerInterface {
+class BlockListBuilder extends ConfigEntityListBuilder implements FormInterface {
 
   /**
    * The regions containing the blocks.
@@ -54,7 +53,7 @@ class BlockListController extends ConfigEntityListController implements FormInte
   protected $blockManager;
 
   /**
    * Constructs a new BlockListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -81,7 +80,7 @@ public static function createInstance(ContainerInterface $container, EntityTypeI
   }
 
   /**
-   * Overrides \Drupal\Core\Config\Entity\ConfigEntityListController::load().
+   * {@inheritdoc}
    */
   public function load() {
     // If no theme was specified, use the current theme.
@@ -102,7 +101,7 @@ public function load() {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::render().
+   * {@inheritdoc}
    *
    * @param string|null $theme
    *   (optional) The theme to display the blocks for. If NULL, the current
@@ -21,9 +20,9 @@
 
 /**
- * Defines the block list controller.
+ * Defines the block list builder.
  */
@@ -54,7 +53,7 @@ class BlockListController extends ConfigEntityListController implements FormInte
 
   /**
-   * Constructs a new BlockListController object.
+   * Constructs a new BlockListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/modules/config/lib/Drupal/config/Tests/ConfigEntityListTest.php b/core/modules/config/lib/Drupal/config/Tests/ConfigEntityListTest.php
index 682aeef..710cc0d 100644
--- a/core/modules/config/lib/Drupal/config/Tests/ConfigEntityListTest.php
+++ b/core/modules/config/lib/Drupal/config/Tests/ConfigEntityListTest.php
@@ -32,10 +32,10 @@ public static function getInfo() {
   }
 
   /**
    * Tests entity list controller methods.
    */
   function testList() {
-    $controller = \Drupal::entityManager()->getListController('config_test');
+    $controller = \Drupal::entityManager()->getListBuilder('config_test');
 
     // Test getStorageController() method.
     $this->assertTrue($controller->getStorageController() instanceof EntityStorageControllerInterface, 'EntityStorageController instance in storage.');
@@ -116,7 +116,7 @@ function testList() {
     // Test that config entities that do not support status, do not have
     // enable/disable operations.
     $controller = $this->container->get('entity.manager')
-      ->getListController('config_test_no_status');
+      ->getListBuilder('config_test_no_status');
 
     $list = $controller->load();
     $entity = $list['default'];
@@ -32,10 +32,10 @@ public static function getInfo() {
 
   /**
-   * Tests entity list controller methods.
+   * Tests entity list builder methods.
    */
   function testList() {
diff --git a/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestListController.php b/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestListBuilder.php
similarity index 68%
rename from core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestListController.php
rename to core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestListBuilder.php
index 564876a..b90625a 100644
--- a/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestListController.php
+++ b/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestListBuilder.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\config_test\ConfigTestListController.
+ * Contains \Drupal\config_test\ConfigTestListBuilder.
  */
 
 namespace Drupal\config_test;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a list controller for config_test.
  */
-class ConfigTestListController extends ConfigEntityListController {
+class ConfigTestListBuilder extends ConfigEntityListBuilder {
 
   /**
    * {@inheritdoc}
@@ -2,18 +2,18 @@
 
 /**
- * Provides a list controller for config_test.
+ * Provides a list builder for config_test entity.
  */
diff --git a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationBlockListController.php b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationBlockListBuilder.php
similarity index 93%
rename from core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationBlockListController.php
rename to core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationBlockListBuilder.php
index 7151954..520fe72 100644
--- a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationBlockListController.php
+++ b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationBlockListBuilder.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\config_translation\Controller\ConfigTranslationBlockListController.
+ * Contains \Drupal\config_translation\Controller\ConfigTranslationBlockListBuilder.
  */
 
 namespace Drupal\config_translation\Controller;
@@ -15,9 +15,9 @@
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
  * Defines the config translation controller for blocks.
  */
-class ConfigTranslationBlockListController extends ConfigTranslationEntityListController {
+class ConfigTranslationBlockListBuilder extends ConfigTranslationEntityListBuilder {
 
   /**
    * An array of theme info keyed by theme name.
@@ -15,9 +15,9 @@
 
 /**
- * Defines the config translation controller for blocks.
+ * Defines the config translation list builder for blocks.
  */
diff --git a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListController.php b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListBuilder.php
similarity index 92%
rename from core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListController.php
rename to core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListBuilder.php
index 8c09840..c4982f7 100644
--- a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListController.php
+++ b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationEntityListBuilder.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\config_translation\Controller\ConfigTranslationEntityListController.
+ * Contains \Drupal\config_translation\Controller\ConfigTranslationEntityListBuilder.
  */
 
 namespace Drupal\config_translation\Controller;
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityListController;
+use Drupal\Core\Entity\EntityListBuilder;
 
 /**
  * Defines the configuration translation controller for entities.
  */
-class ConfigTranslationEntityListController extends EntityListController implements ConfigTranslationEntityListControllerInterface {
+class ConfigTranslationEntityListBuilder extends EntityListBuilder implements ConfigTranslationEntityListBuilderInterface {
 
   /**
    * Provides user facing strings for the filter element.
@@ -2,18 +2,18 @@
 
 /**
- * Defines the configuration translation controller for entities.
+ * Defines the configuration translation list builder for entities.
  */
diff --git a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationFieldInstanceListController.php b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationFieldInstanceListBuilder.php
similarity index 94%
rename from core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationFieldInstanceListController.php
rename to core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationFieldInstanceListBuilder.php
index b708ded..3aa2bbf 100644
--- a/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationFieldInstanceListController.php
+++ b/core/modules/config_translation/lib/Drupal/config_translation/Controller/ConfigTranslationFieldInstanceListBuilder.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\config_translation\Controller\ConfigTranslationFieldInstanceListController.
+ * Contains \Drupal\config_translation\Controller\ConfigTranslationFieldInstanceListBuilder.
  */
 
 namespace Drupal\config_translation\Controller;
@@ -17,9 +17,9 @@
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
  * Defines the config translation controller for field instance entities.
  */
-class ConfigTranslationFieldInstanceListController extends ConfigTranslationEntityListController {
+class ConfigTranslationFieldInstanceListBuilder extends ConfigTranslationEntityListBuilder {
 
   /**
    * The name of the entity type the field instances are attached to.
@@ -62,7 +62,7 @@ public static function createInstance(ContainerInterface $container, EntityTypeI
   }
 
   /**
    * Constructs a new ConfigTranslationFieldInstanceListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -17,9 +17,9 @@
 
 /**
- * Defines the config translation controller for field instance entities.
+ * Defines the config translation list builder for field instance entities.
  */
@@ -62,7 +62,7 @@ public static function createInstance(ContainerInterface $container, EntityTypeI
 
   /**
-   * Constructs a new ConfigTranslationFieldInstanceListController object.
+   * Constructs a new ConfigTranslationFieldInstanceListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/modules/entity/lib/Drupal/entity/EntityDisplayModeListController.php b/core/modules/entity/lib/Drupal/entity/EntityDisplayModeListBuilder.php
similarity index 94%
rename from core/modules/entity/lib/Drupal/entity/EntityDisplayModeListController.php
rename to core/modules/entity/lib/Drupal/entity/EntityDisplayModeListBuilder.php
index d904af2..ce38969 100644
--- a/core/modules/entity/lib/Drupal/entity/EntityDisplayModeListController.php
+++ b/core/modules/entity/lib/Drupal/entity/EntityDisplayModeListBuilder.php
@@ -2,12 +2,12 @@
 
 /**
  * @file
- * Contains \Drupal\entity\EntityDisplayModeListController.
+ * Contains \Drupal\entity\EntityDisplayModeListBuilder.
  */
 
 namespace Drupal\entity;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
@@ -16,7 +16,7 @@
 /**
  * Provides the listing for entity display modes.
  */
-class EntityDisplayModeListController extends ConfigEntityListController {
+class EntityDisplayModeListBuilder extends ConfigEntityListBuilder {
 
   /**
    * All entity types.
@@ -26,7 +26,7 @@ class EntityDisplayModeListController extends ConfigEntityListController {
   protected $entityTypes;
 
   /**
    * Constructs a new EntityListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -26,7 +26,7 @@ class EntityDisplayModeListController extends ConfigEntityListController {
 
   /**
-   * Constructs a new EntityListController object.
+   * Constructs a new EntityDisplayModeListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/modules/field_ui/lib/Drupal/field_ui/FieldListController.php b/core/modules/field_ui/lib/Drupal/field_ui/FieldListBuilder.php
similarity index 93%
rename from core/modules/field_ui/lib/Drupal/field_ui/FieldListController.php
rename to core/modules/field_ui/lib/Drupal/field_ui/FieldListBuilder.php
index 10db033..9520bf0 100644
--- a/core/modules/field_ui/lib/Drupal/field_ui/FieldListController.php
+++ b/core/modules/field_ui/lib/Drupal/field_ui/FieldListBuilder.php
@@ -2,12 +2,12 @@
 
 /**
  * @file
- * Contains \Drupal\field_ui\FieldListController.
+ * Contains \Drupal\field_ui\FieldListBuilder.
  */
 
 namespace Drupal\field_ui;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityManagerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
@@ -17,7 +17,7 @@
 /**
  * Provides a listing of fields.
  */
-class FieldListController extends ConfigEntityListController {
+class FieldListBuilder extends ConfigEntityListBuilder {
 
   /**
    * An array of information about field types.
@@ -48,7 +48,7 @@ class FieldListController extends ConfigEntityListController {
   protected $fieldTypeManager;
 
   /**
    * Constructs a new EntityListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -48,7 +48,7 @@ class FieldListController extends ConfigEntityListController {
 
   /**
-   * Constructs a new EntityListController object.
+   * Constructs a new FieldListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/modules/filter/lib/Drupal/filter/FilterFormatListController.php b/core/modules/filter/lib/Drupal/filter/FilterFormatListBuilder.php
similarity index 91%
rename from core/modules/filter/lib/Drupal/filter/FilterFormatListController.php
rename to core/modules/filter/lib/Drupal/filter/FilterFormatListBuilder.php
index 3b70aea..5fe985f 100644
--- a/core/modules/filter/lib/Drupal/filter/FilterFormatListController.php
+++ b/core/modules/filter/lib/Drupal/filter/FilterFormatListBuilder.php
@@ -2,24 +2,23 @@
 
 /**
  * @file
- * Contains \Drupal\filter\FilterFormatListController.
+ * Contains \Drupal\filter\FilterFormatListBuilder.
  */
 
 namespace Drupal\filter;
 
 use Drupal\Component\Utility\String;
 use Drupal\Core\Config\ConfigFactory;
-use Drupal\Core\Config\Entity\DraggableListController;
-use Drupal\Core\Entity\EntityControllerInterface;
+use Drupal\Core\Config\Entity\DraggableListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
- * Defines the filter format list controller.
+ * Defines the filter format list.
  */
-class FilterFormatListController extends DraggableListController implements EntityControllerInterface {
+class FilterFormatListBuilder extends DraggableListBuilder {
 
   /**
    * {@inheritdoc}
@@ -34,7 +33,7 @@ class FilterFormatListController extends DraggableListController implements Enti
   protected $configFactory;
 
   /**
    * Constructs a new FilterFormatListController.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -34,7 +33,7 @@ class FilterFormatListController extends DraggableListController implements Enti
 
   /**
-   * Constructs a new FilterFormatListController.
+   * Constructs a new FilterFormatListBuilder.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/modules/image/lib/Drupal/image/ImageStyleListController.php b/core/modules/image/lib/Drupal/image/ImageStyleListBuilder.php
similarity index 86%
rename from core/modules/image/lib/Drupal/image/ImageStyleListController.php
rename to core/modules/image/lib/Drupal/image/ImageStyleListBuilder.php
index 568b5be..0a92cf6 100644
--- a/core/modules/image/lib/Drupal/image/ImageStyleListController.php
+++ b/core/modules/image/lib/Drupal/image/ImageStyleListBuilder.php
@@ -2,24 +2,22 @@
 
 /**
  * @file
- * Contains \Drupal\image\ImageStyleListController.
+ * Contains \Drupal\image\ImageStyleListBuilder.
  */
 
 namespace Drupal\image;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
-use Drupal\Core\Entity\EntityControllerInterface;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
 use Drupal\Core\Routing\UrlGeneratorInterface;
-use Drupal\Core\StringTranslation\Translator\TranslatorInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
  * Provides a listing of image styles.
  */
-class ImageStyleListController extends ConfigEntityListController implements EntityControllerInterface {
+class ImageStyleListBuilder extends ConfigEntityListBuilder {
 
   /**
    * The URL generator.
@@ -29,7 +27,7 @@ class ImageStyleListController extends ConfigEntityListController implements Ent
   protected $urlGenerator;
 
   /**
    * Constructs a new ImageStyleListController object.
    *
    * @param EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -29,7 +27,7 @@ class ImageStyleListController extends ConfigEntityListController implements Ent
 
   /**
-   * Constructs a new ImageStyleListController object.
+   * Constructs a new ImageStyleListBuilder object.
    *
    * @param EntityTypeInterface $entity_info
diff --git a/core/modules/node/lib/Drupal/node/NodeListController.php b/core/modules/node/lib/Drupal/node/NodeListBuilder.php
similarity index 93%
rename from core/modules/node/lib/Drupal/node/NodeListController.php
rename to core/modules/node/lib/Drupal/node/NodeListBuilder.php
index c4d01ce..f72a497 100644
--- a/core/modules/node/lib/Drupal/node/NodeListController.php
+++ b/core/modules/node/lib/Drupal/node/NodeListBuilder.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\node\NodeListController.
+ * Contains \Drupal\node\NodeListBuilder.
  */
 
 namespace Drupal\node;
@@ -10,17 +10,16 @@
 use Drupal\Component\Utility\String;
 use Drupal\Core\Datetime\Date;
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityListController;
+use Drupal\Core\Entity\EntityListBuilder;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
 use Drupal\Core\Language\Language;
-use Drupal\Core\StringTranslation\TranslationInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
- * Provides a list controller for nodes.
+ * Provides a list of nodes.
  */
-class NodeListController extends EntityListController {
+class NodeListBuilder extends EntityListBuilder {
 
   /**
    * The date service.
@@ -30,7 +29,7 @@ class NodeListController extends EntityListController {
   protected $dateService;
 
   /**
    * Constructs a new NodeListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -30,7 +29,7 @@ class NodeListController extends EntityListController {
 
   /**
-   * Constructs a new NodeListController object.
+   * Constructs a new NodeListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/modules/search/lib/Drupal/search/SearchPageListController.php b/core/modules/search/lib/Drupal/search/SearchPageListBuilder.php
similarity index 97%
rename from core/modules/search/lib/Drupal/search/SearchPageListController.php
rename to core/modules/search/lib/Drupal/search/SearchPageListBuilder.php
index 4586a6b..09bbd8a 100644
--- a/core/modules/search/lib/Drupal/search/SearchPageListController.php
+++ b/core/modules/search/lib/Drupal/search/SearchPageListBuilder.php
@@ -2,14 +2,14 @@
 
 /**
  * @file
- * Contains \Drupal\search\SearchPageListController.
+ * Contains \Drupal\search\SearchPageListBuilder.
  */
 
 namespace Drupal\search;
 
 use Drupal\Component\Utility\MapArray;
 use Drupal\Core\Config\ConfigFactory;
-use Drupal\Core\Config\Entity\DraggableListController;
+use Drupal\Core\Config\Entity\DraggableListBuilder;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
@@ -19,7 +19,7 @@
 /**
  * Provides a listing of search page entities.
  */
-class SearchPageListController extends DraggableListController implements FormInterface {
+class SearchPageListBuilder extends DraggableListBuilder implements FormInterface {
 
   /**
    * The entities being listed.
@@ -43,7 +43,7 @@ class SearchPageListController extends DraggableListController implements FormIn
   protected $searchManager;
 
   /**
    * Constructs a new SearchPageListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -43,7 +43,7 @@ class SearchPageListController extends DraggableListController implements FormIn
 
   /**
-   * Constructs a new SearchPageListController object.
+   * Constructs a new SearchPageListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/modules/system/lib/Drupal/system/DateFormatListController.php b/core/modules/system/lib/Drupal/system/DateFormatListBuilder.php
similarity index 89%
rename from core/modules/system/lib/Drupal/system/DateFormatListController.php
rename to core/modules/system/lib/Drupal/system/DateFormatListBuilder.php
index 85d63d9..8dd457c 100644
--- a/core/modules/system/lib/Drupal/system/DateFormatListController.php
+++ b/core/modules/system/lib/Drupal/system/DateFormatListBuilder.php
@@ -2,13 +2,13 @@
 
 /**
  * @file
- * Contains \Drupal\system\DateFormatListController.
+ * Contains \Drupal\system\DateFormatListBuilder.
  */
 
 namespace Drupal\system;
 
 use Drupal\Component\Utility\String;
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Datetime\Date;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
@@ -18,7 +18,7 @@
 /**
  * Provides a listing of date formats.
  */
-class DateFormatListController extends ConfigEntityListController {
+class DateFormatListBuilder extends ConfigEntityListBuilder {
 
   /**
    * The date service.
@@ -28,7 +28,7 @@ class DateFormatListController extends ConfigEntityListController {
   protected $dateService;
 
   /**
    * Constructs a new DateFormatListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -28,7 +28,7 @@ class DateFormatListController extends ConfigEntityListController {
 
   /**
-   * Constructs a new DateFormatListController object.
+   * Constructs a new DateFormatListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestListController.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestListBuilder.php
similarity index 70%
rename from core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestListController.php
rename to core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestListBuilder.php
index fddc724..4b8dc26 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestListController.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestListBuilder.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\entity_test\EntityTestListController.
+ * Contains \Drupal\entity_test\EntityTestListBuilder.
  */
 
 namespace Drupal\entity_test;
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityListController;
+use Drupal\Core\Entity\EntityListBuilder;
 
 /**
  * Provides a list controller for entity_test.
  */
-class EntityTestListController extends EntityListController {
+class EntityTestListBuilder extends EntityListBuilder {
 
   /**
    * {@inheritdoc}
@@ -2,18 +2,18 @@
 
 /**
- * Provides a list controller for entity_test.
+ * Provides a list builder for entity_test.
  */
diff --git a/core/modules/user/lib/Drupal/user/Controller/UserListController.php b/core/modules/user/lib/Drupal/user/UserListBuilder.php
similarity index 92%
rename from core/modules/user/lib/Drupal/user/Controller/UserListController.php
rename to core/modules/user/lib/Drupal/user/UserListBuilder.php
index a928b55..a2bb46a 100644
--- a/core/modules/user/lib/Drupal/user/Controller/UserListController.php
+++ b/core/modules/user/lib/Drupal/user/UserListBuilder.php
@@ -2,14 +2,13 @@
 
 /**
  * @file
- * Contains \Drupal\user\Controller\UserListController.
+ * Contains \Drupal\user\UserListBuilder.
  */
 
-namespace Drupal\user\Controller;
+namespace Drupal\user;
 
-use Drupal\Core\Entity\EntityControllerInterface;
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityListController;
+use Drupal\Core\Entity\EntityListBuilder;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
 use Drupal\Core\Entity\Query\QueryFactory;
@@ -20,7 +19,7 @@
  *
  * @see \Drupal\user\Entity\User
  */
-class UserListController extends EntityListController implements EntityControllerInterface {
+class UserListBuilder extends EntityListBuilder {
 
   /**
    * The entity query factory.
@@ -30,7 +29,7 @@ class UserListController extends EntityListController implements EntityControlle
   protected $queryFactory;
 
   /**
    * Constructs a new UserListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   The entity info for the entity type.
@@ -30,7 +29,7 @@ class UserListController extends EntityListController implements EntityControlle
 
   /**
-   * Constructs a new UserListController object.
+   * Constructs a new UserListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/ViewListController.php b/core/modules/views_ui/lib/Drupal/views_ui/ViewListBuilder.php
similarity index 96%
rename from core/modules/views_ui/lib/Drupal/views_ui/ViewListController.php
rename to core/modules/views_ui/lib/Drupal/views_ui/ViewListBuilder.php
index 62ffce8..eb80b68 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/ViewListController.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/ViewListBuilder.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\views_ui\ViewListController.
+ * Contains \Drupal\views_ui\ViewListBuilder.
  */
 
 namespace Drupal\views_ui;
@@ -10,8 +10,7 @@
 use Drupal\Component\Utility\String;
 use Drupal\Component\Plugin\PluginManagerInterface;
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Config\Entity\ConfigEntityListController;
-use Drupal\Core\Entity\EntityControllerInterface;
+use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
@@ -19,7 +18,7 @@
 /**
  * Provides a listing of Views.
  */
-class ViewListController extends ConfigEntityListController implements EntityControllerInterface {
+class ViewListBuilder extends ConfigEntityListBuilder {
 
   /**
    * The views display plugin manager to use.
@@ -40,7 +39,7 @@ public static function createInstance(ContainerInterface $container, EntityTypeI
   }
 
   /**
    * Constructs a new EntityListController object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
    *   An array of entity info for this entity type.
@@ -40,7 +39,7 @@ public static function createInstance(ContainerInterface $container, EntityTypeI
 
   /**
-   * Constructs a new EntityListController object.
+   * Constructs a new ViewListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_info
diff --git a/core/tests/Drupal/Tests/Core/Entity/EntityListControllerTest.php b/core/tests/Drupal/Tests/Core/Entity/EntityListBuilderTest.php
similarity index 64%
rename from core/tests/Drupal/Tests/Core/Entity/EntityListControllerTest.php
rename to core/tests/Drupal/Tests/Core/Entity/EntityListBuilderTest.php
index 6db04b5..e933a82 100644
--- a/core/tests/Drupal/Tests/Core/Entity/EntityListControllerTest.php
+++ b/core/tests/Drupal/Tests/Core/Entity/EntityListBuilderTest.php
@@ -2,41 +2,41 @@
 
 /**
  * @file
- * Contains \Drupal\Tests\Core\Entity\EntityListControllerTest.
+ * Contains \Drupal\Tests\Core\Entity\EntityListBuilderTest.
  */
 
 namespace Drupal\Tests\Core\Entity;
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\entity_test\EntityTestListController;
+use Drupal\entity_test\EntityTestListBuilder;
 use Drupal\Tests\UnitTestCase;
 
 /**
- * Tests the entity list controller.
+ * Tests the entity list.
  *
  * @group Entity
  *
- * @see \Drupal\entity_test\EntityTestListController
+ * @see \Drupal\entity_test\EntityTestListBuilder
  */
-class EntityListControllerTest extends UnitTestCase {
+class EntityListBuilderTest extends UnitTestCase {
 
   /**
    * The entity used to construct the EntityListController.
    *
    * @var \Drupal\user\RoleInterface|\PHPUnit_Framework_MockObject_MockObject
    */
   protected $role;
 
   /**
    * The EntityListController object to test.
    *
-   * @var \Drupal\Core\Entity\EntityListController
+   * @var \Drupal\Core\Entity\EntityListBuilder
    */
-  protected $entityListController;
+  protected $entityList;
 
   public static function getInfo() {
     return array(
-      'name' => 'Entity list controller test',
+      'name' => 'Entity list test',
       'description' => 'Unit test of entity access checking system.',
       'group' => 'Entity'
     );
@@ -52,7 +52,7 @@ protected function setUp() {
     $role_storage_controller = $this->getMock('Drupal\user\RoleStorageControllerInterface');
     $module_handler = $this->getMock('Drupal\Core\Extension\ModuleHandlerInterface');
     $entity_type = $this->getMock('Drupal\Core\Entity\EntityTypeInterface');
-    $this->entityListController = new TestEntityListController($entity_type, $role_storage_controller, $module_handler);
+    $this->entityList = new TestEntityListBuilder($entity_type, $role_storage_controller, $module_handler);
   }
 
   /**
@@ -70,7 +70,7 @@ protected function setUp() {
    * @param bool $ignorewarnings
    *   Whether or not to ignore PHP 5.3+ invalid multibyte sequence warnings.
    *
-   * @see \Drupal\Component\Utility\Drupal\Core\Entity\EntityListController::buildRow()
+   * @see \Drupal\Core\Entity\EntityList::buildRow()
    */
   public function testBuildRow($input, $expected, $message, $ignorewarnings = FALSE) {
     $this->role->expects($this->any())
@@ -78,10 +78,10 @@ public function testBuildRow($input, $expected, $message, $ignorewarnings = FALS
       ->will($this->returnValue($input));
 
     if ($ignorewarnings) {
-      $built_row = @$this->entityListController->buildRow($this->role);
+      $built_row = @$this->entityList->buildRow($this->role);
     }
     else {
-      $built_row = $this->entityListController->buildRow($this->role);
+      $built_row = $this->entityList->buildRow($this->role);
     }
 
     $this->assertEquals($built_row['label'], $expected, $message);
@@ -101,13 +101,13 @@ public function testBuildRow($input, $expected, $message, $ignorewarnings = FALS
   public function providerTestBuildRow() {
     $tests = array();
     // Checks that invalid multi-byte sequences are rejected.
-    $tests[] = array("Foo\xC0barbaz", '', 'EntityTestListController::buildRow() rejects invalid sequence "Foo\xC0barbaz"', TRUE);
-    $tests[] = array("\xc2\"", '', 'EntityTestListController::buildRow() rejects invalid sequence "\xc2\""', TRUE);
-    $tests[] = array("Fooÿñ", "Fooÿñ", 'EntityTestListController::buildRow() accepts valid sequence "Fooÿñ"');
+    $tests[] = array("Foo\xC0barbaz", '', 'EntityTestListBuilder::buildRow() rejects invalid sequence "Foo\xC0barbaz"', TRUE);
+    $tests[] = array("\xc2\"", '', 'EntityTestListBuilder::buildRow() rejects invalid sequence "\xc2\""', TRUE);
+    $tests[] = array("Fooÿñ", "Fooÿñ", 'EntityTestListBuilder::buildRow() accepts valid sequence "Fooÿñ"');
 
     // Checks that special characters are escaped.
-    $tests[] = array("<script>", '&lt;script&gt;', 'EntityTestListController::buildRow() escapes &lt;script&gt;');
-    $tests[] = array('<>&"\'', '&lt;&gt;&amp;&quot;&#039;', 'EntityTestListController::buildRow() escapes reserved HTML characters.');
+    $tests[] = array("<script>", '&lt;script&gt;', 'EntityTestListBuilder::buildRow() escapes &lt;script&gt;');
+    $tests[] = array('<>&"\'', '&lt;&gt;&amp;&quot;&#039;', 'EntityTestListBuilder::buildRow() escapes reserved HTML characters.');
 
     return $tests;
 
@@ -115,7 +115,7 @@ public function providerTestBuildRow() {
 
 }
 
-class TestEntityListController extends EntityTestListController {
+class TestEntityListBuilder extends EntityTestListBuilder {
   public function buildOperations(EntityInterface $entity) {
     return array();
   }
@@ -2,41 +2,41 @@
 
   /**
-   * The entity used to construct the EntityListController.
+   * The entity used to construct the EntityListBuilder.
    *
    * @var \Drupal\user\RoleInterface|\PHPUnit_Framework_MockObject_MockObject
@@ -2,41 +2,41 @@
 
   /**
-   * The EntityListController object to test.
+   * The EntityListBuilder object to test.
    *
diff --git a/core/tests/Drupal/Tests/Core/Entity/EntityManagerTest.php b/core/tests/Drupal/Tests/Core/Entity/EntityManagerTest.php
index 24df3b7..af0adea 100644
--- a/core/tests/Drupal/Tests/Core/Entity/EntityManagerTest.php
+++ b/core/tests/Drupal/Tests/Core/Entity/EntityManagerTest.php
@@ -289,11 +289,11 @@ public function testGetStorageController() {
   }
 
   /**
    * Tests the getListController() method.
    *
-   * @covers ::getListController()
+   * @covers ::getListBuilder()
    */
-  public function testGetListController() {
+  public function testGetListBuilder() {
     $class = $this->getTestControllerClass();
     $entity = $this->getMock('Drupal\Core\Entity\EntityTypeInterface');
     $entity->expects($this->once())
@@ -301,7 +301,7 @@ public function testGetListController() {
       ->will($this->returnValue($class));
     $this->setUpEntityManager(array('test_entity_type' => $entity));
 
-    $this->assertInstanceOf($class, $this->entityManager->getListController('test_entity_type'));
+    $this->assertInstanceOf($class, $this->entityManager->getListBuilder('test_entity_type'));
   }
 
   /**
@@ -289,11 +289,11 @@ public function testGetStorageController() {
 
   /**
-   * Tests the getListController() method.
+   * Tests the getListBuilder() method.
    *
